@@ -164,6 +164,9 @@ def main():
     
     parser_d = subparsers.add_parser('instances', help='instances details of the rack')
     parser_d.set_defaults(which='instances')
+
+    parser_d = subparsers.add_parser('apps', help='apps details of the rack')
+    parser_d.set_defaults(which='apps')
     
     parser_e = subparsers.add_parser('logs', help='logs of a service')
     parser_e.add_argument('--app', '-a', help='application name')
